Contributing Guidelines
#######################

To contribute, please read `CONTRIBUTING.md <https://github.com/JaxLayerLumos/JaxLayerLumos/blob/JOSS/markdowns/CONTRIBUTING.md>`_ for our guidelines on issues, enhancements, and pull requests. Follow the outlined standards to keep the project consistent and collaborative.
